@@ -2,7 +2,6 @@
 Keyring Chainer - iterates over other viable backends to
 discover passwords in each.
 """
-
 from .. import backend
 from .._compat import properties
 from . import fail
@@ -19,7 +18,7 @@ class ChainerBackend(backend.KeyringBackend):
     viable = True
 
     @properties.classproperty
-    def priority(cls):
+    def priority(cls) -> int:
         """
         If there are backends to chain, high priority
         Otherwise very low priority since our operation when empty
