@@ -14,17 +14,17 @@ def _settings_root_Vista():
 def _data_root_Windows():
     release, version, csd, ptype = platform.win32_ver()
     root = _settings_root_XP() if release == 'XP' else _settings_root_Vista()
-    return os.path.join(root, 'Python Keyring')
+    return pathlib.Path(root, 'Python Keyring')
 
 
 def _data_root_Linux():
     """
-    Use freedesktop.org Base Dir Specfication to determine storage
+    Use freedesktop.org Base Dir Specification to determine storage
     location.
     """
     fallback = pathlib.Path.home() / '.local/share'
     root = os.environ.get('XDG_DATA_HOME', None) or fallback
-    return os.path.join(root, 'python_keyring')
+    return pathlib.Path(root, 'python_keyring')
 
 
 _config_root_Windows = _data_root_Windows
@@ -53,16 +53,16 @@ def _check_old_config_root():
 
 def _config_root_Linux():
     """
-    Use freedesktop.org Base Dir Specfication to determine config
+    Use freedesktop.org Base Dir Specification to determine config
     location.
     """
     _check_old_config_root()
     fallback = pathlib.Path.home() / '.config'
     key = 'XDG_CONFIG_HOME'
     root = os.environ.get(key, None) or fallback
-    return os.path.join(root, 'python_keyring')
+    return pathlib.Path(root, 'python_keyring')
 
 
 # by default, use Unix convention
 data_root = globals().get('_data_root_' + platform.system(), _data_root_Linux)
-config_root = globals().get('_config_root' + platform.system(), _config_root_Linux)
+config_root = globals().get('_config_root_' + platform.system(), _config_root_Linux)
